@@ -7,12 +7,11 @@ use parent 'BorderStyleBase';
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-01-24'; # DATE
 our $DIST = 'BorderStyles-Standard'; # DIST
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 our %BORDER = (
     v => 2,
     summary => 'Just like ASCII::SingleLine but uses double line to separate header row and first data row',
-    dynamic => 1,
     chars => [
         ['.','-','+','.'], # 0
         ['|','|','|'],     # 1
@@ -24,39 +23,10 @@ our %BORDER = (
         [], # 6
         [], # 7
 
-        ['+','=','+','+', '+','+','+','+'], # 8 - separator between header rows
+        ['+','-','+','+', '+','+','+','+'], # 8 - separator between header rows
     ],
-    args => {
-        header_row_count => {
-            summary => 'Number of header rows',
-            schema => 'uint*',
-            default => 1,
-            description => <<'_',
-
-This argument is useful if you have multiple header rows.
-
-_
-        },
-    },
 );
 
-sub get_border_char {
-    my ($self, $y, $x, $n, $args) = @_;
-    $args = {} unless defined $args;
-
-    my $in_header = defined $args->{rownum} ?
-        $args->{rownum} < $self->{args}{header_row_count} :
-        ($y >= 0 && $y <= 2 || $y == 8);
-    #use DD; dd $self->{args}; dd $args; dd {in_header=>$in_header, y=>$y, x=>$x, n=>$n};
-    if ($in_header) {
-        if ($y == 3) { $y = 1 }
-        elsif ($y == 4) { $y = 8 }
-    }
-    #use DD; dd {y=>$y, x=>$x, n=>$n};
-
-    $self->SUPER::get_border_char($y, $x, $n, $args);
-}
-
 1;
 # ABSTRACT: Just like ASCII::SingleLine but uses double line to separate header row and first data row
 
@@ -72,7 +42,7 @@ BorderStyle::ASCII::SingleLineDoubleAfterHeader - Just like ASCII::SingleLine bu
 
 =head1 VERSION
 
-This document describes version 0.008 of BorderStyle::ASCII::SingleLineDoubleAfterHeader (from Perl distribution BorderStyles-Standard), released on 2022-01-24.
+This document describes version 0.009 of BorderStyle::ASCII::SingleLineDoubleAfterHeader (from Perl distribution BorderStyles-Standard), released on 2022-01-24.
 
 =head1 SYNOPSIS
 
